betty.test_utils.ancestry.description - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
Toggle table of contents sidebar

# Source code for betty.test_utils.ancestry.description

    """
    Test utilities for :py:mod:`betty.ancestry.description`.
    """

    from betty.ancestry.description import HasDescription

    class DummyHasDescription(HasDescription):
        """
        A dummy :py:class:`betty.ancestry.description.HasDescription` implementation.
        """

        pass